@@ -1,15 +1,13 @@
 #
-# $Id: String.pm,v 0.02 2004/01/02 00:30:33 st.schubiger Exp $
+# $Id: String.pm,v 0.03 2004/01/02 03:35:03 st.schubiger Exp $
 
 package Convert::ASCII::String;
 
 use strict;
 use warnings;
 
-use Carp;
-
-use base qw(Exporter);
 require Exporter;
+use base qw(Exporter);
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
 
@@ -17,7 +15,7 @@ our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =head1 NAME
 
@@ -83,8 +81,11 @@ Convert a character string to ASCII inserting a separator between each ASCII cod
 
 sub string2ascii {
     my ($data_ref, $sep) = @_;
-    croak q~usage: string2ascii (\$data, $separator)~
-      unless ref $data_ref eq 'SCALAR' && $sep;
+    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'};
+    unless (ref $data_ref eq 'SCALAR' && $sep) {
+        require Carp;
+        Carp::croak q~usage: string2ascii (\$data, $separator)~;
+    }
 
     my @ascii = unpack 'C*', $$data_ref;
     $$data_ref = join $sep, @ascii;
@@ -100,12 +101,15 @@ And vice versa.
 
 sub ascii2string {
     my ($data_ref, $sep) = @_;
-    croak q~usage: ascii2string (\$data, $separator)~
-      unless ref $data_ref eq 'SCALAR' && $sep;
+    no strict 'refs'; $sep ||= ${__PACKAGE__.'::Sep'};
+    unless (ref $data_ref eq 'SCALAR' && $sep) {
+        require Carp;
+        Carp::croak q~usage: ascii2string (\$data, $separator)~;
+    }
 
     $sep = quotemeta $sep;
     my @ascii = split $sep, $$data_ref;
-    $$data_ref = pack 'C*', @ascii;
+    $$data_ref = pack 'C*', @ascii;      
 }
 
 1;
@@ -119,6 +123,14 @@ C<string2ascii()> and C<ascii2string()> upon request.
 
 :all - C<*()>
 
+=head1 OPTIONS
+
+The separator may alternatively be set by
+
+ $Convert::ASCII::String::Sep = '.';
+
+Function delivery becomes then superfluous.
+
 =head1 SEE ALSO
 
 perl(1)
